
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/mitol/mail:mitol-django-mail

from setuptools import setup

setup(**{
    'authors': [
        'MIT Office of Open Learning <mitx-devops@mit.edu>',
    ],
    'classifiers': [
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    'description': 'MIT Open Learning django app extensions for mail',
    'license': 'BSD 3-Clause License',
    'name': 'mitol-django-mail',
    'version': '3.0.0',
    'zip_safe': True,
    'package_dir': {
        '': 'src',
    },
    'packages': (
        'mitol',
        'mitol.mail',
        'mitol.mail.settings',
    ),
    'namespace_packages': (
        'mitol',
    ),
    'package_data': {
        'mitol.mail': (
            'CHANGELOG.md',
            'README.md',
            'py.typed',
            'templates/mail/email_base.html',
            'templates/mail/email_debugger.html',
            'templates/mail/partials/_logo.html',
        ),
    },
    'install_requires': (
        'beautifulsoup4>=4.6.0',
        'django-anymail>=6.0',
        'django>=2.2.12',
        'html5lib>=1.1',
        'mitol-django-common~=2.0.0',
        'premailer>=3.7.0',
        'toolz>=0.10.0',
    ),
})
